@@ -6,27 +6,31 @@ use URI;
 
 use overload '""' => "as_string", fallback => 1;
 
-sub as_string;
+sub as_string;  # help overload find it
 
 sub new
 {
     my($class, $uri, $base) = @_;
     my $ibase = $base;
-    if ($base && UNIVERSAL::isa($base, "URI::WithBase")) {
+    if ($base && ref($base) && UNIVERSAL::isa($base, "URI::WithBase")) {
 	$base = $base->abs;
 	$ibase = $base->[0];
     }
     bless [URI->new($uri, $ibase), $base], $class;
 }
 
+sub new_abs
+{
+    my $class = shift;
+    my $self = $class->new(@_);
+    $self->abs;
+}
+
 sub _init
 {
     my $class = shift;
-    my($str, $base, $scheme) = @_;
-    die "Assertion failed" unless UNIVERSAL::isa($base, "URI::WithBase");
-    $base = $base->abs;
-    my $ibase = $base->[0];
-    bless [URI->new($str, $ibase), $base], $class;
+    my($str, $scheme) = @_;
+    bless [URI->new($str, $scheme), undef], $class;
 }
 
 sub eq
@@ -44,12 +48,21 @@ sub AUTOLOAD
     $self->[0]->$method(@_);
 }
 
+sub can {                                  # override UNIVERSAL::can
+    my $self = shift;
+    $self->SUPER::can(@_) || (
+      ref($self)
+      ? $self->[0]->can(@_)
+      : undef
+    )
+}
+
 sub base {
     my $self = shift;
     my $base  = $self->[1];
 
     if (@_) { # set
-	my $new_base = @_;
+	my $new_base = shift;
 	$new_base = $new_base->abs if ref($new_base);  # ensure absoluteness
 	$self->[1] = $new_base;
     }
@@ -70,7 +83,9 @@ sub base {
 sub clone
 {
     my $self = shift;
-    bless [$self->[0]->clone, $self->[0]], ref($self);
+    my $base = $self->[1];
+    $base = $base->clone if ref($base);
+    bless [$self->[0]->clone, $base], ref($self);
 }
 
 sub abs
@@ -88,3 +103,57 @@ sub rel
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+URI::WithBase - URI which remember their base
+
+=head1 SYNOPSIS
+
+ $u1 = URI::WithBase->new($str, $base);
+ $u2 = $u1->abs;
+
+ $base = $u1->base;
+ $u1->base( $new_base )
+
+=head1 DESCRIPTION
+
+This module provide the C<URI::WithBase> class.  Objects of this class
+are like C<URI> objects, but can keep their base too.
+
+The methods provided in addition to or modified from those of C<URI> are:
+
+=over 4
+
+=item $uri = URI::WithBase->new($str, [$base])
+
+The constructor takes a an optional base URI as the second argument.
+
+=item $uri->base( [$new_base] )
+
+This method can be used to get or set the value of the base attribute.
+
+=item $uri->abs( [$base_uri] )
+
+The $base_uri argument is now made optional as the object carries it's
+base with it.
+
+=item $uri->rel( [$base_uri] )
+
+The $base_uri argument is now made optional as the object carries it's
+base with it.
+
+=back
+
+
+=head1 SEE ALSO
+
+L<URI>
+
+=head1 COPYRIGHT
+
+Copyright 1998-2000 Gisle Aas.
+
+=cut
